-----------------------------------------------------------------------------
--
-- data
--   \dispel
--     \<playerName>
--       - count
--
-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("AssessmentDispel")
L:RegisterTranslations("enUS", function() return {
	["Dispellers List"] = true,
	["Dispels"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Dispellers List"] = "해제 목록",
	["Dispels"] = "해제",
} end)

-----------------------------------------------------------------------------

local AssessmentDispel = Assessment:NewModule("Dispel", "AceEvent-2.0", "Parser-3.0")
AssessmentDispel.db = Assessment:AcquireDBNamespace("Dispel")
Assessment:RegisterDefaults("Dispel", "profile", {
	enable = true
})

-----------------------------------------------------------------------------

local emptyMethod = Assessment.EmptyMethod
local new = Assessment.NewTable
local pairs = pairs

-----------------------------------------------------------------------------

Assessment.TagData.DispelCount =
{
	method = function(data)
				local fightData = data.fightData
				if not fightData then return 0 end
				
				local dispel = fightData.dispel
				if not dispel then return 0 end
				
				local playerDispel = dispel[data.key]
				if not playerDispel then return 0 end

				return playerDispel.count
			 end,
	data = "dispel",
	guaranteeResult = true,
	numeric = true,
}

-----------------------------------------------------------------------------

Assessment.ListType.Dispellers =
{
	method = function(fightData)
				if not fightData.dispel then return emptyMethod end
				return pairs(fightData.dispel)
			 end,
	data = "dispel",
	description = L["Dispellers List"],
}

-----------------------------------------------------------------------------

Assessment.DefaultDisplaySets.Dispels =
{
	titleTag		= L["Dispels"],
	listType		= "Dispellers", 
	barValueTag		= "DispelCount", 
	filterTag		= "BarValue ~= 0",
	fightIndex		= 0,
	description		= L["Dispels"],
	defaultColor	= { 0.5, 0.3, 0.8 },
	colorTypeList	= { "Class", count = 1 },
}

-----------------------------------------------------------------------------

function AssessmentDispel:OnInitialize()
end

function AssessmentDispel:OnEnable()
	self:RegisterParserEvent({ eventType = "Dispel" }, "OnParserDispelEvent")
end

function AssessmentDispel:OnDisable()
end

-----------------------------------------------------------------------------

function AssessmentDispel:OnParserDispelEvent(eventData)
	if not eventData.sourceName or eventData.isFailed then return end

	local time = GetTime()
	for data in self:IterateUpdateDataTables() do
		data.dataUpdateTimes.dispel = time
		local dispel = data.dispel
		if not dispel then
			dispel = new()
			data.dispel = dispel
		end

		local playerDispel = dispel[eventData.sourceName]
		if playerDispel then
			playerDispel.count = playerDispel.count + 1
		else
			playerDispel = new()
			playerDispel.count = 1
			dispel[eventData.sourceName] = playerDispel
		end
	end
end

-----------------------------------------------------------------------------
